@@ -18,17 +18,16 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from __future__ import absolute_import
-
 import gzip
 import os
 import os.path
-import six
+from pathlib import Path
+import re
 import sys
 import tempfile
-import re
+import urllib.parse
 
-import unittest
+import pytest
 
 from debian import debian_support
 from debian.debian_support import *
@@ -52,27 +51,25 @@ def find_test_file(filename):
     return os.path.abspath(os.path.join(os.path.dirname(__file__), filename))
 
 
-class VersionTests(unittest.TestCase):
+class TestVersion:
     """Tests for AptPkgVersion and NativeVersion classes in debian_support"""
 
-    def setUp(self):
-        # type: () -> None
-        if debian_support._have_apt_pkg:
-            self.test_classes = [AptPkgVersion, NativeVersion]
-        else:
-            self.test_classes = [NativeVersion]
+    if debian_support._have_apt_pkg:
+        test_classes = [AptPkgVersion, NativeVersion]
+    else:
+        test_classes = [NativeVersion]
 
     def _test_version(self, full_version, epoch, upstream, debian):
         # type: (str, Optional[str], str, Optional[str]) -> None
         for cls in self.test_classes:
             v = cls(full_version)
-            self.assertEqual(v.full_version, full_version,
-                             "%s: full_version broken" % cls)
-            self.assertEqual(v.epoch, epoch, "%s: epoch broken" % cls)
-            self.assertEqual(v.upstream_version, upstream,
-                             "%s: upstream_version broken" % cls)
-            self.assertEqual(v.debian_revision, debian,
-                             "%s: debian_revision broken" % cls)
+            assert v.full_version == full_version, \
+                             "%s: full_version broken" % cls
+            assert v.epoch == epoch, "%s: epoch broken" % cls
+            assert v.upstream_version == upstream, \
+                             "%s: upstream_version broken" % cls
+            assert v.debian_revision == debian, \
+                             "%s: debian_revision broken" % cls
 
     def testversions(self):
         # type: () -> None
@@ -102,8 +99,8 @@ class VersionTests(unittest.TestCase):
                            '1ubuntu1')
         self._test_version('2:1.0.4~rc2-1', '2', '1.0.4~rc2', '1')
         for cls in self.test_classes:
-            self.assertRaises(
-                ValueError, cls, 'a1:1.8.8-070403-1~priv1')
+            with pytest.raises(ValueError):
+                cls('a1:1.8.8-070403-1~priv1')
 
     def test_version_updating(self):
         # type: () -> None
@@ -111,24 +108,24 @@ class VersionTests(unittest.TestCase):
             v = cls('1:1.4.1-1')
 
             v.debian_version = '2'
-            self.assertEqual(v.debian_version, '2')
-            self.assertEqual(v.full_version, '1:1.4.1-2')
+            assert v.debian_version == '2'
+            assert v.full_version == '1:1.4.1-2'
 
             v.upstream_version = '1.4.2'
-            self.assertEqual(v.upstream_version, '1.4.2')
-            self.assertEqual(v.full_version, '1:1.4.2-2')
+            assert v.upstream_version == '1.4.2'
+            assert v.full_version == '1:1.4.2-2'
 
             v.epoch = '2'
-            self.assertEqual(v.epoch, '2')
-            self.assertEqual(v.full_version, '2:1.4.2-2')
+            assert v.epoch == '2'
+            assert v.full_version == '2:1.4.2-2'
 
-            self.assertEqual(str(v), v.full_version)
+            assert str(v) == v.full_version
 
             v.full_version = '1:1.4.1-1'
-            self.assertEqual(v.full_version, '1:1.4.1-1')
-            self.assertEqual(v.epoch, '1')
-            self.assertEqual(v.upstream_version, '1.4.1')
-            self.assertEqual(v.debian_version, '1')
+            assert v.full_version == '1:1.4.1-1'
+            assert v.epoch == '1'
+            assert v.upstream_version == '1.4.1'
+            assert v.debian_version == '1'
 
     @staticmethod
     def _get_truth_fn(cmp_oper):
@@ -172,8 +169,8 @@ class VersionTests(unittest.TestCase):
             v1 = cls1(v1_str)
             v2 = cls2(v2_str)
             truth_fn = self._get_truth_fn(cmp_oper)
-            self.assertTrue(truth_fn(v1, v2) == True,
-                            "%r %s %r != True" % (v1, cmp_oper, v2))
+            assert truth_fn(v1, v2) == True, \
+                            "%r %s %r != True" % (v1, cmp_oper, v2)
 
     def test_comparisons(self):
         # type: () -> None
@@ -202,26 +199,26 @@ class VersionTests(unittest.TestCase):
         self._test_comparison('1.5~rc1', '>', '1.5~dev0')
 
 
-class ReleaseTests(unittest.TestCase):
+class TestRelease:
     """Tests for debian_support.Release"""
 
     def test_comparison(self):
         # type: () -> None
-        self.assertLess(intern_release('buzz'), intern_release('hamm'))
-        self.assertLess(intern_release('sarge'), intern_release('etch'))
-        self.assertLess(intern_release('lenny'), intern_release('squeeze'))
+        assert intern_release('buzz') < intern_release('hamm')
+        assert intern_release('sarge') < intern_release('etch')
+        assert intern_release('lenny') < intern_release('squeeze')
 
 
-class HelperRoutineTests(unittest.TestCase):
+class TestHelperRoutine:
     """Tests for various debian_support helper routines"""
 
     def test_read_lines_sha1(self):
         # type: () -> None
         empty = []  # type: List[bytes]
-        self.assertEqual(read_lines_sha1(empty),
-                         'da39a3ee5e6b4b0d3255bfef95601890afd80709')
-        self.assertEqual(read_lines_sha1(['1\n', '23\n']),
-                         '14293c9bd646a15dc656eaf8fba95124020dfada')
+        assert read_lines_sha1(empty) == \
+                         'da39a3ee5e6b4b0d3255bfef95601890afd80709'
+        assert read_lines_sha1(['1\n', '23\n']) == \
+                         '14293c9bd646a15dc656eaf8fba95124020dfada'
 
     def test_patch_lines(self):
         # type: () -> None
@@ -233,7 +230,7 @@ class HelperRoutineTests(unittest.TestCase):
                  '9,10d\n', '6d\n', '2,3c\n', '<2>\n', '<3>\n', '.\n', '0a\n',
                  '0\n', '.\n']
         patch_lines(file_a, patches_from_ed_script(patch))
-        self.assertEqual(''.join(file_b), ''.join(file_a))
+        assert ''.join(file_b) == ''.join(file_a)
 
     def test_patch_lines_bytes(self):
         # type: () -> None
@@ -246,17 +243,18 @@ class HelperRoutineTests(unittest.TestCase):
                  b'0\n', b'.\n']
         patch_re_bytes = re.compile(b"^(\\d+)(?:,(\\d+))?([acd])$")
         patch_lines(file_a, patches_from_ed_script(patch, re_cmd=patch_re_bytes))
-        self.assertEqual(b''.join(file_b), b''.join(file_a))
+        assert b''.join(file_b) == b''.join(file_a)
 
 
-class PdiffTests(unittest.TestCase):
+class TestPdiff:
     """ Tests for functions dealing with pdiffs """
 
     def test_download_gunzip_lines(self):
         # type: () -> None
         filename = find_test_file('test_Packages.diff/test_Packages.1.gz')
-        lines = download_gunzip_lines("file://" + filename)
-        self.assertTrue(len(lines))
+        filename_uri = Path(filename).as_uri()
+        lines = download_gunzip_lines(filename_uri)
+        assert len(lines)
 
     def test_update_file(self):
         # type: () -> None
@@ -264,6 +262,7 @@ class PdiffTests(unittest.TestCase):
         original = find_test_file('test_Packages')
         # The 'remote' location from which the update will be made
         remote = find_test_file('test_Packages')
+        remote_uri = Path(remote).as_uri()
         # A correctly updated file for comparison
         updated = find_test_file('test_Packages_pdiff_updated')
 
@@ -276,32 +275,26 @@ class PdiffTests(unittest.TestCase):
             fp.close()
 
             # run the update
-            update_file("file://" + remote, copy, verbose=False)
+            update_file(remote_uri, copy, verbose=False)
 
             # check that the updated copy is the same as the known-good file
             with open(copy) as oh, open(updated) as uh:
-                self.assertEqual(oh.read(), uh.read())
+                assert oh.read() == uh.read()
 
         finally:
             os.remove(copy)
 
 
-class PackageFileTests(unittest.TestCase):
+class TestPackageFile:
     """ Tests for functions dealing with Packages and Sources """
 
-    def assertType(self, var_, type_):
-        # type: (Any, Any) -> None
-        """Check that the type is as expected
-        """
-        self.assertTrue(isinstance(var_, type_))
-
     def test_read_file(self):
         # type: () -> None
         # test_Packages is ASCII
         packfile = find_test_file('test_Packages')
         pf = debian_support.PackageFile(packfile)
         pflist = list(pf)
-        self.assertEqual(len(pflist), 3)
+        assert len(pflist) == 3
         pf.file.close()
 
         # test_Sources is UTF-8
@@ -309,7 +302,7 @@ class PackageFileTests(unittest.TestCase):
         packfile = find_test_file('test_Sources')
         pf = debian_support.PackageFile(packfile)
         pflist = list(pf)
-        self.assertEqual(len(pflist), 4)
+        assert len(pflist) == 4
         pf.file.close()
 
     def test_read_fileobj(self):
@@ -318,14 +311,10 @@ class PackageFileTests(unittest.TestCase):
         with open(packfile, 'rb') as fhbin:
             pf = debian_support.PackageFile('ignored', file_obj=fhbin)
             pflist = list(pf)
-            self.assertEqual(len(pflist), 3)
-            self.assertType(pflist[0][0][1], six.string_types)
+            assert len(pflist) == 3
+            assert isinstance(pflist[0][0][1], str)
         with open(packfile, 'rt') as fhtext:
             pf = debian_support.PackageFile('ignored', file_obj=fhtext)
             pflist = list(pf)
-            self.assertEqual(len(pflist), 3)
-            self.assertType(pflist[0][0][1], six.string_types)
-
-
-if __name__ == "__main__":
-    unittest.main()
+            assert len(pflist) == 3
+            assert isinstance(pflist[0][0][1], str)
